#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "No ejecute el script app_upgrade directamente. Para actualizar una aplicación, ejecute el siguiente mandato:"
echo "    relm_upgrade"
echo "Utilice -help para obtener una descripción completa del mandato anterior."
;;

INVALID_START_DIR )
echo ""
echo "Salvo cuando se utiliza el parámetro -help, el script $2 no puede ejecutarse desde otro directorio que no sea $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "El archivo '$2' contiene los valores de parámetro para el script de actualización."
echo "Si necesita modificar alguno de los valores de parámetro predeterminados, puede editar estos archivos o puede especificar los valores de parámetro como argumentos de línea de mandatos en los scripts de actualización."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "El siguiente archivo contiene los valores de predeterminados para una actualización de aplicación. Si necesita modificar alguno de los valores de parámetro predeterminados, puede editar el archivo o puede especificar los valores de parámetro como argumentos de línea de mandatos en el script de actualización."
echo "- Actualización de RELM:  $2/params/relm_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "No se ha especificado ningún tipo de aplicación. Para actualizar la aplicación, ejecute el siguiente mandato:"
echo "    relm_upgrade"
echo "Utilice -help para obtener una descripción completa del mandato anterior."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 no es un tipo de aplicación válido. Para actualizar la aplicación, ejecute el siguiente mandato:"
echo "    relm_upgrade"
echo "Utilice -help para obtener una descripción completa del mandato anterior."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Falta el valor para el parámetro $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "El directorio $3, especificado para el parámetro $2, no existe o no es válido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "El directorio $3 especificado para el parámetro $2 debe ser una vía de acceso absoluta."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "El archivo $3, especificado para el parámetro $2, no existe o no es válido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 no es un valor válido para el parámetro $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 es un parámetro desconocido."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Falta el parámetro del directorio de inicio $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "El directorio $2 no existe o no es válido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el mandato repotools de aplicación '$2'."
echo ""
echo "Verifique que el parámetro -oldApplicationHome '$3' apunte al directorio de configuración del servidor anterior, por ejemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el mandato repotools de aplicación '$2'."
echo ""
echo "Verifique que el parámetro -oldApplicationHome '$3' apunta al directorio de configuración del servidor anterior, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Verifique que el parámetro -oldApplicationHome '$3' apunte al directorio de configuración del servidor anterior, por ejemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Verifique que el parámetro -oldApplicationHome '$3' apunta al directorio de configuración del servidor anterior, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el mandato repotools de aplicación '$2'."
echo ""
echo "Verifique que el parámetro -newApplicationHome '$3' apunta al directorio de configuración del servidor de aplicaciones nuevo, por ejemplo, 'JazzInstallDir/server/conf', y que el parámetro jtsContextRoot '$4' es correcto."
echo "Si está actualizando desde una versión anterior, asegúrese de haber seleccionado las raíces de contexto correctas. Por ejemplo, si utiliza Installation Manager, debe seleccionar la opción de raíz de contexto $5 del panel "Context Root Options" . Si ha seleccionado por accidente una opción diferente, debe volver a instalar el producto con la opción de raíz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Verifique que el parámetro -newApplicationHome '$3' apunta al directorio de configuración del servidor JTS nuevo, por ejemplo, 'JazzInstallDir/server/conf', y que el parámetro jtsContextRoot '$4' es correcto."
echo "Si está actualizando desde una versión anterior, asegúrese de haber seleccionado las raíces de contexto correctas. Por ejemplo, si utiliza Installation Manager, debe seleccionar la opción de raíz de contexto $5 del panel "Context Root Options" . Si ha seleccionado por accidente una opción diferente, debe volver a instalar el producto con la opción de raíz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Verifique que el parámetro -oldJTSHome '$3' apunta al directorio de configuración del servidor JTS anterior, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Verifique que el parámetro -oldJTSHome '$3' apunta al directorio de configuración del servidor JTS anterior, por ejemplo, 'JazzInstallDir/server/conf' y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el mandato repotools de JTS '$2'."
echo ""
echo "Verifique que el parámetro -newJTSHome '$3' apunta al directorio de configuración del servidor JTS nuevo, por ejemplo, 'JazzInstallDir/server/conf', y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "No se puede encontrar el archivo de configuración '$2'."
echo ""
echo "Verifique que el parámetro -newJTSHome '$3' apunta al directorio de configuración del servidor JTS nuevo, por ejemplo, 'JazzInstallDir/server/conf', y que el parámetro jtsContextRoot '$4' es correcto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Se necesita un archivo tar que contenga datos 2.x para la actualización de $2."
echo "Utilice -help para obtener una descripción completa de los parámetros."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_relm )
echo ""
echo ""
echo "============================================"
echo "===    Actualización de RELM    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "La última ejecución ha fallado en el paso inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "La última ejecución ha fallado en el paso $2..."
echo "¿Desea reiniciar la actualización desde este paso o desde uno anterior?"
;;

ALREADY_RUN )
echo ""
echo "La actualización ha se ha realizado y ha finalizado correctamente..."
echo "¿Desea realizar una nueva desde a partir de un paso determinado?"
;;

LAST_STEP_PASSED )
echo ""
echo "La última ejecución se ha detenido correctamente en el paso $2..."
echo "¿Desea reiniciar la actualización desde el paso $3 actual o desde uno anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Especifique el número de paso [$2-$3] desde el que desea reiniciar la actualización o pulse [Intro] para cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' no es un número. Especifique un número de paso válido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' no es un número de paso válido. Especifique un número de paso válido."
;;

MAX_STEP_NUMBER )
echo ""
echo "El último paso es el paso $2, por consiguiente, no puede reiniciar la actualización a partir del paso $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "El paso $2 todavía no se ha ejecutado, por consiguiente, no puede reiniciar la actualización en el paso $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Paso 0: Descartar tablas"
echo "------------------"
;;

STEP_0 )
echo "Paso 0: Actualizar archivos de configuración"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Paso 1: Añadir tablas"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Paso $2: Volver a crear índices de texto"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "Paso $2: Volver a crear índices de consulta y de búsqueda"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Paso 2: Actualizar el esquema de depósito de datos"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "La actualización de $2 ha fallado en el paso $3. Corrija el problema y ejecute de nuevo el script a partir del paso $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_RELM )
echo ""
echo "La actualización de $2 ha sido satisfactoria. Si también ha actualizado JTS y cualquier aplicación dependiente (como VVC, LQE y Sparql_Gateway), puede iniciar los servidores en el despliegue."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Directorio: $2"
echo "Mandato:"
;;

ENTER_STEP_ACTION )
echo "Especifique [E] para ejecutar este paso, [S] para omitirlo, o pulse [Intro] para cancelar la ejecución del script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' no es una entrada válida, sólo se permite 'E', 'S' o 'Intro'."
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Se abrirá un editor vi para que pueda verificar el archivo $2 teamserver.properties."
echo "Verifique que la raíz del URI público marcada por la propiedad com.ibm.team.repository.server.webapp.url es correcta."
echo "Verifique que las propiedades de la base de datos son correctas."
echo "Cuando lo haya hecho, guarde los cambios si los hubiera y cierre el editor para continuar con la ejecución del script."
echo ""
;;

PAUSE )
echo ""
echo "Especifique [C] para continuar con la ejecución del script o pulse [Intro] para cancelarla:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' no es una entrada válida, sólo se permite 'C' o 'Intro'."
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "No se han podido copiar los índices de texto de '$2' a '$3'."
echo "Verifique la propiedad com.ibm.team.fulltext.indexLocation"
echo "definida en el archivo teamserver.properties."
echo "Copie manualmente los índices de texto en este directorio"
echo "o ejecute repotools -rebuildTextIndices para volver a crearlos."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "No existe ningún URI público definido en"
echo "$3"
echo "por consiguiente, no se puede iniciar la actualización."
echo ""
echo "Debe haber un URI público en este archivo definido de este modo:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad de URI público com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Añada la propiedad al archivo teamserver.properties de la instalación anterior y establezca el valor en la raíz del URI que todos los clientes utilizan para localizar el servidor."
echo "La raíz de URI público es esencial para el correcto funcionamiento de la nueva instalación. La actualización no se realizará correctamente sin esta propiedad.  "
echo "Para obtener más información, consulte el tema del InfoCenter sobre 'Planificación de sus URI'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todos los URI públicos definidos en"
echo "$3"
echo "están comentados, por consiguiente, no se puede iniciar la actualización."
echo ""
echo "Debe haber un URI público sin comentario en este archivo definido de este modo:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propiedad de URI público com.ibm.team.repository.server.webapp.url debe estar presente en el archivo teamserver.properties."
echo "Añada la propiedad al archivo teamserver.properties de la instalación anterior y establezca el valor en la raíz del URI que todos los clientes utilizan para localizar el servidor."
echo "La raíz de URI público es esencial para el correcto funcionamiento de la nueva instalación. La actualización no se realizará correctamente sin esta propiedad."
echo "Para obtener más información, consulte el tema del InfoCenter sobre 'Planificación de sus URI'."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "La raíz de contexto para JTS está establecida en '$2'."
echo "La raíz de contexto para la aplicación está establecida en '$3'."
echo "La raíz de contexto no puede ser la misma para JTS y para la aplicación."
echo ""
;;

esac

}
