#!/bin/sh
# *******************************************************************************
#  Materiales bajo licencia - Propiedad de IBM
#  (c) Copyright IBM Corporation 2006, 2012. Reservados todos los derechos.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Defina las variables de entorno correspondientes a los    #
# # parmetros del script relm_upgrade.sh y sus valores       #
# # predeterminados.                                          #
# #===========================================================
# #
# # Este archivo se lee al comienzo de la ejecucin del       #
# # script relm_upgrade.sh. Define una variable de entorno por
# # cada parmetro vlido con un valor predeterminado
# #
# # Es posible que los usuarios deseen modificar el valor predeterminado
# # para lanzar el script relm_upgrade.sh con sus propios valores
# # sin tener que especificar de forma manual el parmetro y su
# # valor correspondiente en la lnea de mandatos.
# #
# # AVISO:
# # No es necesario definir todas las variables para cada
# # aplicacin.  Lea cada comentario detenidamente antes de modificar
# # el valor.
# #
# #############################################################

# Parameter: -oldApplicationHome
# Uso: -oldApplicationHome <va acceso dir>
# Descripcin:
# 	Va de acceso completa al directorio de inicio de la aplicacin en instalaciones antiguas.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - es un parmetro obligatorio
#  - <va acceso dir> debe ser un directorio existente terminado en 'server\conf'
#    e.g. /opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# Parmetro: -applicationContextRoot
# Uso: -applicationContextRoot <root>
# Descripcin:
# 	Raz de contexto de aplicacin.
# Valor predeterminado:
# 	relm
# Restricciones:
#  - <raz> debe ser un nombre nico de directorio vlido (es decir, ninguna barra inclinada inicial)
#
APPLICATION_CONTEXT_ROOT=relm

# Parmetro: -oldApplicationVersion
# Uso: -oldApplicationVersion <version>
# Descripcin:
# 	La versin RELM que se est actualizando.  De forma predeterminada, se
#     determina ejecutando repotools -version en la aplicacin anterior.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Debe ser una serie de la versin completa
#    e.g. 1.0.0.1
#
OLD_APPLICATION_VERSION=

# Parmetro: -newApplicationHome
# Uso: -newApplicationHome <va acceso dir>
# Descripcin:
# 	Va de acceso al directorio de inicio de la aplicacin de la nueva instalacin.
# Valor predeterminado:
# 	<currentDir>/conf
# Restricciones:
#  - Es un parmetro obligatorio
#  - <dir path> debe ser un directorio existente terminado en 'server\conf'
#     e.g. /opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parmetro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descripcin:
# 	Si deben actualizarse los archivos de configuracin tomcat.
# Valor predeterminado:
# 	yes
# Restricciones:
#  - Los nicos valores vlidos son 'yes' y 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parmetro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <va acceso dir>
# Descripcin:
# 	Va de acceso completa al directorio raz de Tomcat en la instalacin anterior.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Debe ser un directorio existente
#
OLD_APP_TOMCAT_HOME=

# Parmetro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <va acceso dir>
# Descripcin:
# 	Va de acceso al directorio raz de Tomcat de la aplicacin de la nueva instalacin.
# Valor predeterminado:
# 	<ninguno>
#
NEW_APP_TOMCAT_HOME=

# Parmetro: -newJTSHome
# Uso: -newJTSHome <va acceso dir>
# Descripcin:
# 	Va de acceso al directorio de configuracin de servidor JTS del JTS que utilizar la nueva instalacin.
# Valor predeterminado:
# 	El nuevo directorio de inicio de aplicacin
# Restricciones:
#  - <va_acceso_dir> debe ser un directorio existente que termine en 'server\conf'
#
NEW_JTS_HOME=

# Parmetro: -jtsContextRoot
# Uso: -jtsContextRoot <raz>
# Descripcin:
# 	Raz de contexto del servidor JTS.
# Valor predeterminado:
# 	jts
# Restricciones:
#  - <raz> debe ser un nombre nico de directorio vlido (es decir, ninguna barra inclinada inicial)
#
JTS_CONTEXT_ROOT=jts

# Parmetro: -noPrompt
# Uso: -noPrompt
# Descripcin:
# 	No mostrar solicitud antes de crear o modificar las tablas
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los nicos valores vlidos son en blanco o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parmetro: -noVerify
# Uso: -noVerify
# Descripcin:
# 	No realizar verificacin de los archivos teamserver.properties.
# Valor predeterminado:
# 	<ninguno>
# Restricciones:
#  - Los nicos valores vlidos son en blanco o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parmetro: -overwrite
# Uso: -overwrite
# Descripcin:
# 	Si debe sobrescribirse algn archivo existente.
# Valor predeterminado:
# 	no
# Restricciones:
#  - Los nicos valores vlidos son en blanco u 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parmetro: -noStepPrompt
# Uso: -noStepPrompt
# Descripcin:
# 	No mostrar solicitud antes de ejecutar un paso.
# Valor predeterminado:
# 	false
# Restricciones:
#  - Los nicos valores vlidos son 'true' o 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
